@@ -2,12 +2,22 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: MittelmannDistCntrlNeumA.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: MittelmannDistCntrlNeumA.cpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-11-05
 
 #include "MittelmannDistCntrlNeumA.hpp"
 
+#ifdef HAVE_CASSERT
+# include <cassert>
+#else
+# ifdef HAVE_ASSERT_H
+#  include <assert.h>
+# else
+#  error "don't have header file for assert"
+# endif
+#endif
+
 using namespace Ipopt;
 
 /* Constructor. */
