@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpAlgBuilder.cpp 2028 2011-06-30 18:32:37Z andreasw $
+// $Id: IpAlgBuilder.cpp 2346 2013-07-01 13:03:35Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-09-29
 
@@ -59,6 +59,7 @@
 #include "IpMa57TSolverInterface.hpp"
 #include "IpMa77SolverInterface.hpp"
 #include "IpMa86SolverInterface.hpp"
+#include "IpMa97SolverInterface.hpp"
 #include "IpMc19TSymScalingMethod.hpp"
 #include "IpPardisoSolverInterface.hpp"
 #include "IpSlackBasedTSymScalingMethod.hpp"
@@ -71,8 +72,10 @@
 # include "IpMumpsSolverInterface.hpp"
 #endif
 
-#include "HSLLoader.h"
-#include "PardisoLoader.h"
+#ifdef HAVE_LINEARSOLVERLOADER
+# include "HSLLoader.h"
+# include "PardisoLoader.h"
+#endif
 
 namespace Ipopt
 {
@@ -137,7 +140,7 @@ namespace Ipopt
   void AlgorithmBuilder::RegisterOptions(SmartPtr<RegisteredOptions> roptions)
   {
     roptions->SetRegisteringCategory("Linear Solver");
-    roptions->AddStringOption8(
+    roptions->AddStringOption9(
       "linear_solver",
       "Linear solver used for step computations.",
 #ifdef COINHSL_HAS_MA27
@@ -146,19 +149,27 @@ namespace Ipopt
 # ifdef COINHSL_HAS_MA57
       "ma57",
 # else
-#  ifdef COINHSL_HAS_MA86
-      "ma86",
-#  else
-#   ifdef HAVE_PARDISO
-      "pardiso",
+# ifdef COINHSL_HAS_MA97
+      "ma97",
+#else
+#   ifdef COINHSL_HAS_MA86
+       "ma86",
 #   else
-#    ifdef HAVE_WSMP
-      "wsmp",
+#    ifdef HAVE_PARDISO
+       "pardiso",
 #    else
-#     ifdef COIN_HAS_MUMPS
-      "mumps",
+#     ifdef HAVE_WSMP
+       "wsmp",
 #     else
-      "ma27",
+#      ifdef COIN_HAS_MUMPS
+       "mumps",
+#      else
+#       ifdef COINHSL_HAS_MA77
+        "ma77",
+#       else
+        "ma27",
+#       endif
+#      endif
 #     endif
 #    endif
 #   endif
@@ -169,6 +180,7 @@ namespace Ipopt
       "ma57", "use the Harwell routine MA57",
       "ma77", "use the Harwell routine HSL_MA77",
       "ma86", "use the Harwell routine HSL_MA86",
+      "ma97", "use the Harwell routine HSL_MA97",
       "pardiso", "use the Pardiso package",
       "wsmp", "use WSMP package",
       "mumps", "use MUMPS package",
@@ -297,15 +309,17 @@ namespace Ipopt
 #ifndef COINHSL_HAS_MA27
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma27TSolverInterface();
-      char buf[256];
-      int rc = LSL_loadHSL(NULL, buf, 255);
-      if (rc) {
-        std::string errmsg;
-        errmsg = "Selected linear solver MA27 not available.\nTried to obtain MA27 from shared library \"";
-        errmsg += LSL_HSLLibraryName();
-        errmsg += "\", but the following error occured:\n";
-        errmsg += buf;
-        THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+      if (!LSL_isMA27available()) {
+        char buf[256];
+        int rc = LSL_loadHSL(NULL, buf, 255);
+        if (rc) {
+          std::string errmsg;
+          errmsg = "Selected linear solver MA27 not available.\nTried to obtain MA27 from shared library \"";
+          errmsg += LSL_HSLLibraryName();
+          errmsg += "\", but the following error occured:\n";
+          errmsg += buf;
+          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        }
       }
 # else
       THROW_EXCEPTION(OPTION_INVALID, "Support for MA27 has not been compiled into Ipopt.");
@@ -319,15 +333,17 @@ namespace Ipopt
 #ifndef COINHSL_HAS_MA57
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma57TSolverInterface();
-      char buf[256];
-      int rc = LSL_loadHSL(NULL, buf, 255);
-      if (rc) {
-        std::string errmsg;
-        errmsg = "Selected linear solver MA57 not available.\nTried to obtain MA57 from shared library \"";
-        errmsg += LSL_HSLLibraryName();
-        errmsg += "\", but the following error occured:\n";
-        errmsg += buf;
-        THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+      if (!LSL_isMA57available()) {
+        char buf[256];
+        int rc = LSL_loadHSL(NULL, buf, 255);
+        if (rc) {
+          std::string errmsg;
+          errmsg = "Selected linear solver MA57 not available.\nTried to obtain MA57 from shared library \"";
+          errmsg += LSL_HSLLibraryName();
+          errmsg += "\", but the following error occured:\n";
+          errmsg += buf;
+          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        }
       }
 # else
       THROW_EXCEPTION(OPTION_INVALID, "Support for MA57 has not been compiled into Ipopt.");
@@ -339,24 +355,43 @@ namespace Ipopt
     }
     else if (linear_solver=="ma77") {
 #ifndef COINHSL_HAS_MA77
-      THROW_EXCEPTION(OPTION_INVALID, "Support for MA77 has not been compiled into Ipopt.");
+# ifdef HAVE_LINEARSOLVERLOADER
+      SolverInterface = new Ma77SolverInterface();
+      if (!LSL_isMA77available()) {
+        char buf[256];
+        int rc = LSL_loadHSL(NULL, buf, 255);
+        if (rc) {
+          std::string errmsg;
+          errmsg = "Selected linear solver HSL_MA77 not available.\nTried to obtain HSL_MA77 from shared library \"";
+          errmsg += LSL_HSLLibraryName();
+          errmsg += "\", but the following error occured:\n";
+          errmsg += buf;
+          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        }
+      }
+# else
+      THROW_EXCEPTION(OPTION_INVALID, "Support for HSL_MA77 has not been compiled into Ipopt.");
+# endif
 #else
       SolverInterface = new Ma77SolverInterface();
 #endif
+
     }
     else if (linear_solver=="ma86") {
 #ifndef COINHSL_HAS_MA86
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma86SolverInterface();
-      char buf[256];
-      int rc = LSL_loadHSL(NULL, buf, 255);
-      if (rc) {
-        std::string errmsg;
-        errmsg = "Selected linear solver HSL_MA86 not available.\nTried to obtain HSL_MA86 from shared library \"";
-        errmsg += LSL_HSLLibraryName();
-        errmsg += "\", but the following error occured:\n";
-        errmsg += buf;
-        THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+      if (!LSL_isMA86available()) {
+        char buf[256];
+        int rc = LSL_loadHSL(NULL, buf, 255);
+        if (rc) {
+          std::string errmsg;
+          errmsg = "Selected linear solver HSL_MA86 not available.\nTried to obtain HSL_MA86 from shared library \"";
+          errmsg += LSL_HSLLibraryName();
+          errmsg += "\", but the following error occured:\n";
+          errmsg += buf;
+          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        }
       }
 # else
       THROW_EXCEPTION(OPTION_INVALID, "Support for HSL_MA86 has not been compiled into Ipopt.");
@@ -387,6 +422,30 @@ namespace Ipopt
       SolverInterface = new PardisoSolverInterface();
 #endif
 
+    }
+    else if (linear_solver=="ma97") {
+#ifndef COINHSL_HAS_MA97
+# ifdef HAVE_LINEARSOLVERLOADER
+      SolverInterface = new Ma97SolverInterface();
+      if (!LSL_isMA97available()) {
+        char buf[256];
+        int rc = LSL_loadHSL(NULL, buf, 255);
+        if (rc) {
+          std::string errmsg;
+          errmsg = "Selected linear solver HSL_MA97 not available.\nTried to obtain HSL_MA97 from shared library \"";
+          errmsg += LSL_HSLLibraryName();
+          errmsg += "\", but the following error occured:\n";
+          errmsg += buf;
+          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        }
+      }
+# else
+      THROW_EXCEPTION(OPTION_INVALID, "Support for HSL_MA97 has not been compiled into Ipopt.");
+# endif
+#else
+      SolverInterface = new Ma97SolverInterface();
+#endif
+
     }
     else if (linear_solver=="wsmp") {
 #ifdef HAVE_WSMP
@@ -430,8 +489,8 @@ namespace Ipopt
       std::string linear_system_scaling;
       if (!options.GetStringValue("linear_system_scaling",
                                   linear_system_scaling, prefix)) {
-        // By default, don't use mc19 for non-HSL solvers
-        if (linear_solver!="ma27" && linear_solver!="ma57") {
+        // By default, don't use mc19 for non-HSL solvers, or HSL_MA97
+        if (linear_solver!="ma27" && linear_solver!="ma57" && linear_solver!="ma77" && linear_solver!="ma86") {
           linear_system_scaling="none";
         }
       }
@@ -439,13 +498,15 @@ namespace Ipopt
 #ifndef COINHSL_HAS_MC19
 # ifdef HAVE_LINEARSOLVERLOADER
         ScalingMethod = new Mc19TSymScalingMethod();
-        char buf[256];
-        int rc = LSL_loadHSL(NULL, buf, 255);
-        if (rc) {
-          std::string errmsg;
-          errmsg = "Selected linear system scaling method MC19 not available.\n";
-          errmsg += buf;
-          THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+        if (!LSL_isMC19available()) {
+          char buf[256];
+          int rc = LSL_loadHSL(NULL, buf, 255);
+          if (rc) {
+            std::string errmsg;
+            errmsg = "Selected linear system scaling method MC19 not available.\n";
+            errmsg += buf;
+            THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+          }
         }
 # else
         THROW_EXCEPTION(OPTION_INVALID, "Support for MC19 has not been compiled into Ipopt.");
