@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2011 International Business Machines and others.
+// Copyright (C) 2004, 2012 International Business Machines and others.
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpIpoptAlg.cpp 2008 2011-06-11 16:23:59Z stefan $
+// $Id: IpIpoptAlg.cpp 2199 2013-04-13 11:05:54Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -138,7 +138,7 @@ namespace Ipopt
       // ComputeSearchDirection below
       if (new_options->GetStringValue("corrector_type", string_option, prefix)) {
         ASSERT_EXCEPTION(string_option=="none", OPTION_INVALID,
-                         "If mehrotra_algorithm=yes, corrector_type must be \"afnone\".");
+                         "If mehrotra_algorithm=yes, corrector_type must be \"none\".");
       }
       else {
         new_options->SetStringValue("corrector_type", "none", false);
@@ -955,9 +955,11 @@ namespace Ipopt
 #   ifndef COINHSL_HAS_MA86
 #    ifndef HAVE_PARDISO
 #     ifndef HAVE_WSMP
+#      ifndef IPOPT_NOMUMPSNOTE
     jnlst.Printf(J_INSUPPRESSIBLE, J_MAIN,
                  "NOTE: You are using Ipopt by default with the MUMPS linear solver.\n"
                  "      Other linear solvers might be more efficient (see Ipopt documentation).\n\n\n");
+#      endif
 #     endif
 #    endif
 #   endif
