@@ -2,11 +2,19 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMa28TDependencyDetector.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpMa28TDependencyDetector.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Andreas Waechter            IBM    2007-04-17
 
 #include "IpoptConfig.h"
+
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
+// if we do not have MA28 in HSL or the linear solver loader, then we want to build the MA28 interface
+#if defined(COINHSL_HAS_MA28) || defined(HAVE_LINEARSOLVERLOADER)
+
 #include "IpMa28TDependencyDetector.hpp"
 
 /** Prototypes for MA28's Fortran auxilliary function */
@@ -108,3 +116,5 @@ namespace Ipopt
   }
 
 } // namespace Ipopt
+
+#endif /* COINHSL_HAS_MA28 or HAVE_LINEARSOLVERLOADER */
