@@ -2,11 +2,19 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMc19TSymScalingMethod.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpMc19TSymScalingMethod.cpp 2010 2011-06-11 16:37:45Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-03-17
 
 #include "IpoptConfig.h"
+
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
+// if we do not have MC19 in HSL or the linear solver loader, then we want to build the MC19 interface
+#if defined(COINHSL_HAS_MC19) || defined(HAVE_LINEARSOLVERLOADER)
+
 #include "IpMc19TSymScalingMethod.hpp"
 
 #ifdef HAVE_CMATH
@@ -168,3 +176,5 @@ namespace Ipopt
   }
 
 } // namespace Ipopt
+
+#endif /* COINHSL_HAS_MC19 or HAVE_LINEARSOLVERLOADER */
