@@ -1,4 +1,4 @@
-// Copyright (C) 2006, 2009 Damien Hocking, KBC Advanced Technologies
+// Copyright (C) 2006, 2012 Damien Hocking, KBC Advanced Technologies
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
@@ -10,15 +10,11 @@
 //           (major revision)
 //           (incorporated by AW on 2006-11-11 into Ipopt package)
 
-// The first header to include is the one for MPI.  We need to make sure
-// that we are using C calling mangling
-extern "C"
-{
-  // The following line is a fix for otherwise twice-defined global variable
-  // (This would have to be taken out for a parallel MUMPS version!)
-# define MPI_COMM_WORLD IPOPT_MPI_COMM_WORLD
-# include "mpi.h"
-}
+// The following line is a fix for otherwise twice-defined global variable
+// (This would have to be taken out for a parallel MUMPS version!)
+#define MPI_COMM_WORLD IPOPT_MPI_COMM_WORLD
+// The first header to include is the one for MPI.  
+#include "mpi.h"
 
 #include "IpMumpsSolverInterface.hpp"
 
@@ -60,9 +56,9 @@ namespace Ipopt
     DMUMPS_STRUC_C* mumps_ = new DMUMPS_STRUC_C;
     int argc=1;
     char ** argv = 0;
-    int myid, ierr;
-    ierr = MPI_Init(&argc, &argv);
-    ierr = MPI_Comm_rank(MPI_COMM_WORLD, &myid);
+    int myid;
+    MPI_Init(&argc, &argv);
+    MPI_Comm_rank(MPI_COMM_WORLD, &myid);
     mumps_->n = 0;
     mumps_->nz = 0;
     mumps_->a = NULL;
@@ -137,7 +133,7 @@ namespace Ipopt
     roptions->AddNumberOption(
       "mumps_dep_tol",
       "Pivot threshold for detection of linearly dependent constraints in MUMPS.",
-      -1.,
+      0.0,
       "When MUMPS is used to determine linearly dependent constraints, this "
       "is determines the threshold for a pivot to be considered zero.  This "
       "is CNTL(3) in MUMPS.");
