@@ -1,14 +1,24 @@
-// Copyright (C) 2005, 2008 International Business Machines and others.
+// Copyright (C) 2005, 2011 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpTripletToCSRConverter.cpp 1692 2010-06-21 19:10:07Z andreasw $
+// $Id: IpTripletToCSRConverter.cpp 2087 2012-02-16 11:12:26Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2005-03-13
 
 #include "IpTripletToCSRConverter.hpp"
 #include <list>
 
+#ifdef HAVE_CSTDDEF
+# include <cstddef>
+#else
+# ifdef HAVE_STDDEF_H
+#  include <stddef.h>
+# else
+#  error "don't have header file for stddef"
+# endif
+#endif
+
 namespace Ipopt
 {
 #if COIN_IPOPT_VERBOSITY > 0
@@ -202,6 +212,7 @@ namespace Ipopt
       }
       delete[] ipos_double_triplet_tmp;
       delete[] ipos_double_compressed_tmp;
+      num_doubles_ = nonzeros_triplet_ - nonzeros_compressed_;
     }
     else { // hf_==Full_Format
 
@@ -257,6 +268,7 @@ namespace Ipopt
 
       // Set nonzeros_compressed_ to correct size
       nonzeros_compressed_ = nonzeros_compressed_full;
+      num_doubles_ = idouble_full;
     }
 
     initialized_ = true;
@@ -292,7 +304,7 @@ namespace Ipopt
     for (Index i=0; i<nonzeros_compressed_; i++) {
       a_compressed[i] = a_triplet[ipos_first_[i]];
     }
-    for (Index i=0; i<nonzeros_triplet_-nonzeros_compressed_; i++) {
+    for (Index i=0; i<num_doubles_; i++) {
       a_compressed[ipos_double_compressed_[i]] +=
         a_triplet[ipos_double_triplet_[i]];
     }
