@@ -2,14 +2,11 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: AmplTNLP.cpp 2020 2011-06-16 20:46:16Z andreasw $
+// $Id: AmplTNLP.cpp 2386 2013-09-12 10:50:10Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
 #include "IpoptConfig.h"
-#ifndef PACKAGE_VERSION
-#define PACKAGE_VERSION IPOPT_VERSION
-#endif
 
 #include "AmplTNLP.hpp"
 #include "IpDenseVector.hpp"
@@ -107,17 +104,23 @@ namespace Ipopt
 
     // check the problem statistics (see Table 1 in AMPL doc)
     DBG_ASSERT(n_var > 0); // need some continuous variables
-    if (!allow_discrete && (nbv>0 || niv>0) ) {
-      jnlst_->Printf(J_WARNING, J_MAIN, "==> Warning: Treating %d binary and %d integer variables as continous.\n\n", nbv, niv);
+    if (!allow_discrete && (nbv>0 || niv>0 || nlvbi>0 || nlvci>0 || nlvoi>0) ) {
+      jnlst_->Printf(J_WARNING, J_MAIN, "==> Warning: Treating %d binary and %d integer variables as continous.\n\n", nbv, niv+nlvbi+nlvci+nlvoi);
       allow_discrete = true;
     }
     allow_discrete = true;
-    ASSERT_EXCEPTION(allow_discrete || (nbv == 0 && niv == 0),
+    ASSERT_EXCEPTION(allow_discrete || (nbv == 0 && niv == 0 && nlvbi == 0 && nlvci == 0 && nlvoi == 0),
                      IpoptException,
                      "Discrete variables not allowed when the allow_discrete flag is false, "
                      "Either remove the integer variables, or change the flag in the constructor of AmplTNLP"
                     );
 
+    if (n_cc != 0) {
+      jnlst_->Printf(J_ERROR, J_MAIN, "\n\n***** Currently, the AMPL interface to Ipopt does not support\n      complementarity constraints.  Aborting. *****\n\n");
+      ASSERT_EXCEPTION(n_cc == 0, IpoptException,
+		       "Currently, the AMPL interface to Ipopt does not support complementarity constraints.");
+    }
+
     DBG_ASSERT(nlo == 0 || nlo == 1); // Can handle nonlinear obj.
     DBG_ASSERT(nwv == 0); // Don't know what "linear arc" variables are
     DBG_ASSERT(nlnc == 0); // Don't know what "nonlinear network"constraints are
@@ -398,16 +401,9 @@ namespace Ipopt
     DBG_ASSERT(n == n_var);
     DBG_ASSERT(m == n_con);
 
-    if (init_x) {
-      for (Index i=0; i<n; i++) {
-        if (havex0[i]) {
-          x[i] = X0[i];
-        }
-        else {
-          x[i] = 0.0;
-        }
-      }
-    }
+    if (init_x)
+      for (Index i=0; i<n; i++)
+        x[i] = havex0[i] ? X0[i] : Max(LUv[2*i], Min(LUv[2*i+1], 0.0));
 
     if (init_z) {
       // Modified for warm-start from AMPL
@@ -415,31 +411,14 @@ namespace Ipopt
       const double* zL_init = suffix_handler_->GetNumberSuffixValues("ipopt_zL_in", AmplSuffixHandler::Variable_Source);
       const double* zU_init = suffix_handler_->GetNumberSuffixValues("ipopt_zU_in", AmplSuffixHandler::Variable_Source);
       for (Index i=0; i<n; i++) {
-        if (zL_init) {
-          z_L[i]=zL_init[i];
-        }
-        else {
-          z_L[i] =1.0;
-        }
-        if (zU_init) {
-          z_U[i]=zU_init[i];
-        }
-        else {
-          z_U[i] =1.0;
-        }
+        z_L[i] = zL_init != NULL ?  obj_sign_ * zL_init[i] : 1.0;
+        z_U[i] = zU_init != NULL ? -obj_sign_ * zU_init[i] : 1.0;
       }
     }
 
-    if (init_lambda) {
-      for (Index i=0; i<m; i++) {
-        if (havepi0[i]) {
-          lambda[i] = pi0[i];
-        }
-        else {
-          lambda[i] = 0.0;
-        }
-      }
-    }
+    if (init_lambda)
+      for (Index i=0; i<m; i++)
+        lambda[i] = havepi0[i] ? -obj_sign_ * pi0[i] : 0.0;
 
     return true;
   }
@@ -569,7 +548,7 @@ namespace Ipopt
       DBG_ASSERT(k==nele_hess);
       return true;
     }
-    else if (!iRow & !jCol && values) {
+    else if (!iRow && !jCol && values) {
       if (!apply_new_x(new_x, n, x)) {
         return false;
       }
@@ -626,10 +605,22 @@ namespace Ipopt
     }
 
     IpBlasDcopy(n, x, 1, x_sol_, 1);
-    IpBlasDcopy(n, z_L, 1, z_L_sol_, 1);
-    IpBlasDcopy(n, z_U, 1, z_U_sol_, 1);
     IpBlasDcopy(m, g, 1, g_sol_, 1);
-    IpBlasDcopy(m, lambda, 1, lambda_sol_, 1);
+    if( obj_sign_ == -1.0 ) // maximization
+    {
+      for( int i = 0; i < n; ++i )
+        z_L_sol_[i] = -z_L[i];
+      IpBlasDcopy(n, z_U, 1, z_U_sol_, 1);
+      IpBlasDcopy(m, lambda, 1, lambda_sol_, 1);
+    }
+    else
+    {
+      IpBlasDcopy(n, z_L, 1, z_L_sol_, 1);
+      for( int i = 0; i < n; ++i )
+        z_U_sol_[i] = -z_U[i];
+      for( int i = 0; i < m; ++i )
+        lambda_sol_[i] = -lambda[i];
+    }
     obj_sol_ = obj_value;
 
     std::string message;
@@ -666,7 +657,7 @@ namespace Ipopt
       solve_result_num = 501;
     }
     else if (status == DIVERGING_ITERATES) {
-      message = "Iterates divering; problem might be unbounded.";
+      message = "Iterates diverging; problem might be unbounded.";
       solve_result_num = 300;
     }
     else {
@@ -681,7 +672,7 @@ namespace Ipopt
     }
 
     // Write the .sol file
-    message = " \nIpopt " PACKAGE_VERSION ": " + message;
+    message = " \nIpopt " IPOPT_VERSION ": " + message;
     write_solution_file(message.c_str());
   }
 
@@ -997,6 +988,8 @@ namespace Ipopt
       nkeywds_ = 0;
     }
 
+    /* PrintLatex(jnlst); */
+
     Index n_options = NumberOfAmplOptions();
     keyword* keywords = new keyword[n_options];
 
@@ -1045,6 +1038,59 @@ namespace Ipopt
     return keywds_;
   }
 
+  void AmplOptionsList::MakeValidLatexString(std::string source, std::string& dest) const
+  {
+    std::string::iterator c;
+    for (c=source.begin(); c!=source.end(); c++) {
+      if (*c == '_') {
+        dest.append("\\_");
+      }
+      else if (*c == '^') {
+        dest.append("\\^");
+      }
+      else if (*c == '>' || *c == '<') {
+        ;
+      }
+      else if (*c == '\n') {
+        dest += ", ";
+      }
+      else {
+        dest += *c;
+      }
+    }
+  }
+
+  void AmplOptionsList::PrintLatex(SmartPtr<const Journalist> jnlst)
+  {
+     jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, "\\begin{description}\n");
+     for( std::map<std::string, SmartPtr<const AmplOption> >::iterator iter = ampl_options_map_.begin();
+          iter != ampl_options_map_.end(); ++iter)
+     {
+        std::string amplname;
+        std::string ipoptname;
+        std::string descr;
+
+        MakeValidLatexString(iter->first.c_str(), amplname);
+        MakeValidLatexString(iter->second->IpoptOptionName(), ipoptname);
+        MakeValidLatexString(iter->second->Description(), descr);
+
+        if( ipoptname.length() > 0 )
+        {
+           jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, "\\item[{\\htmlref{%s}{opt:%s}}]",
+              amplname.c_str(), iter->second->IpoptOptionName().c_str());
+           if( amplname != ipoptname )
+              jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, " (Ipopt name: \\htmlref{%s}{opt:%s})",
+                 ipoptname.c_str(), iter->second->IpoptOptionName().c_str());
+        }
+        else
+        {
+           jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, "\\item[%s]", amplname.c_str());
+        }
+        jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, " %s\n", descr.c_str());
+     }
+     jnlst->Printf(J_SUMMARY, J_DOCUMENTATION, "\\end{description}\n");
+  }
+
   char*
   AmplTNLP::get_options(const SmartPtr<OptionsList>& options,
                         SmartPtr<AmplOptionsList>& ampl_options_list,
@@ -1066,7 +1112,7 @@ namespace Ipopt
     ampl_options_list->AddAmplOption("outlev",
                                      "print_level",
                                      AmplOptionsList::Integer_Option,
-                                     "Verbosity level (same as print_level)");
+                                     "Verbosity level");
     ampl_options_list->AddAmplOption("print_user_options",
                                      "print_user_options",
                                      AmplOptionsList::String_Option,
@@ -1100,7 +1146,7 @@ namespace Ipopt
     ampl_options_list->AddAmplOption("maxit",
                                      "max_iter",
                                      AmplOptionsList::Integer_Option,
-                                     "Maximum number of iterations (same as max_iter)");
+                                     "Maximum number of iterations");
     ampl_options_list->AddAmplOption("max_cpu_time",
                                      "max_cpu_time",
                                      AmplOptionsList::Number_Option,
@@ -1352,7 +1398,7 @@ namespace Ipopt
                                              (void**)&nerror_);
 
     static const char sname_default[] = "ipopt";
-    static const char bsname_default[] = "Ipopt " PACKAGE_VERSION;
+    static const char bsname_default[] = "Ipopt " IPOPT_VERSION;
     static const char opname_default[] = "ipopt_options";
     const char* sname;
     const char* bsname;
