@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2010 International Business Machines and others.
+// Copyright (C) 2004, 2012 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpIpoptApplication.cpp 1692 2010-06-21 19:10:07Z andreasw $
+// $Id: IpIpoptApplication.cpp 2346 2013-07-01 13:03:35Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-09-02
 
@@ -21,6 +21,10 @@
 #include "IpCGPenaltyRegOp.hpp"
 #include "IpNLPBoundsRemover.hpp"
 
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
 #ifdef BUILD_INEXACT
 # include "IpInexactRegOp.hpp"
 # include "IpInexactAlgBuilder.hpp"
@@ -56,8 +60,7 @@ namespace Ipopt
       :
       read_params_dat_(true),
       inexact_algorithm_(false),
-      replace_bounds_(false),
-      skip_finalize_solution_call_(false)
+      replace_bounds_(false)
   {
     options_ = new OptionsList();
     if (create_empty)
@@ -92,7 +95,7 @@ namespace Ipopt
       THROW_EXCEPTION(IPOPT_APPLICATION_ERROR,
                       "Caught unknown Ipopt exception");
     }
-    catch (std::bad_alloc) {
+    catch (std::bad_alloc&) {
       jnlst_->Printf(J_ERROR, J_MAIN, "\nEXIT: Not enough memory.\n");
       THROW_EXCEPTION(IPOPT_APPLICATION_ERROR,
                       "Not enough memory");
@@ -114,8 +117,7 @@ namespace Ipopt
       reg_options_(reg_options),
       options_(options),
       inexact_algorithm_(false),
-      replace_bounds_(false),
-      skip_finalize_solution_call_(false)
+      replace_bounds_(false)
   {}
 
   SmartPtr<IpoptApplication> IpoptApplication::clone()
@@ -128,46 +130,10 @@ namespace Ipopt
     retval->read_params_dat_ = read_params_dat_;
     retval->inexact_algorithm_ = inexact_algorithm_;
     retval->replace_bounds_ = replace_bounds_;
-    retval->skip_finalize_solution_call_ = skip_finalize_solution_call_;
 
     return retval;
   }
 
-  ApplicationReturnStatus
-  IpoptApplication::Initialize(std::string params_file /*= "ipopt.opt"*/)
-  {
-    std::string option_file_name;
-    options_->GetStringValue("option_file_name", option_file_name, "");
-    if (option_file_name != "") {
-      if (params_file !="") {
-        jnlst_->Printf(J_SUMMARY, J_MAIN, "Using option file \"%s\".\n\n",
-                       option_file_name.c_str());
-      }
-      params_file = option_file_name;
-    }
-
-    std::ifstream is;
-    if (params_file != "") {
-      try {
-        is.open(params_file.c_str());
-      }
-      catch (std::bad_alloc) {
-        jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Not enough memory.\n");
-        return Insufficient_Memory;
-      }
-      catch (...) {
-        IpoptException exc("Unknown Exception caught in ipopt", "Unknown File", -1);
-        exc.ReportException(*jnlst_);
-        return NonIpopt_Exception_Thrown;
-      }
-    }
-    ApplicationReturnStatus retval = Initialize(is);
-    if (is) {
-      is.close();
-    }
-    return retval;
-  }
-
   ApplicationReturnStatus
   IpoptApplication::Initialize(std::istream& is)
   {
@@ -251,9 +217,14 @@ namespace Ipopt
           options_to_print.push_back("print_level");
           options_to_print.push_back("print_user_options");
           options_to_print.push_back("print_options_documentation");
+          options_to_print.push_back("print_frequency_iter");
+          options_to_print.push_back("print_frequency_time");
           options_to_print.push_back("output_file");
           options_to_print.push_back("file_print_level");
           options_to_print.push_back("option_file_name");
+          options_to_print.push_back("print_info_string");
+          options_to_print.push_back("inf_pr_output");
+          options_to_print.push_back("print_timing_statistics");
 
           options_to_print.push_back("#Termination");
           options_to_print.push_back("tol");
@@ -302,6 +273,7 @@ namespace Ipopt
           options_to_print.push_back("mu_oracle");
           options_to_print.push_back("quality_function_max_section_steps");
           options_to_print.push_back("fixed_mu_oracle");
+          options_to_print.push_back("adaptive_mu_globalization");
           options_to_print.push_back("mu_init");
           options_to_print.push_back("mu_max_fact");
           options_to_print.push_back("mu_max");
@@ -362,18 +334,25 @@ namespace Ipopt
 
           options_to_print.push_back("#Quasi-Newton");
           options_to_print.push_back("hessian_approximation");
+          options_to_print.push_back("limited_memory_update_type");
           options_to_print.push_back("limited_memory_max_history");
           options_to_print.push_back("limited_memory_max_skipping");
+          options_to_print.push_back("limited_memory_initialization");
+          options_to_print.push_back("limited_memory_init_val");
+          options_to_print.push_back("limited_memory_init_val_max");
+          options_to_print.push_back("limited_memory_init_val_min");
+          options_to_print.push_back("limited_memory_special_for_resto");
 
           options_to_print.push_back("#Derivative Test");
           options_to_print.push_back("derivative_test");
           options_to_print.push_back("derivative_test_perturbation");
           options_to_print.push_back("derivative_test_tol");
           options_to_print.push_back("derivative_test_print_all");
+          options_to_print.push_back("derivative_test_first_index");
           options_to_print.push_back("point_perturbation_radius");
 
           // Special linear solver
-#if defined(HAVE_MA27) || defined(HAVE_LINEARSOLVERLOADER)
+#if defined(COINHSL_HAS_MA27) || defined(HAVE_LINEARSOLVERLOADER)
 
           options_to_print.push_back("#MA27 Linear Solver");
           options_to_print.push_back("ma27_pivtol");
@@ -383,7 +362,7 @@ namespace Ipopt
           options_to_print.push_back("ma27_meminc_factor");
 #endif
 
-#if defined(HAVE_MA57) || defined(HAVE_LINEARSOLVERLOADER)
+#if defined(COINHSL_HAS_MA57) || defined(HAVE_LINEARSOLVERLOADER)
 
           options_to_print.push_back("#MA57 Linear Solver");
           options_to_print.push_back("ma57_pivtol");
@@ -396,7 +375,7 @@ namespace Ipopt
           options_to_print.push_back("ma57_small_pivot_flag");
 #endif
 
-#if defined(HAVE_MA77)
+#if defined(COINHSL_HAS_MA77) || defined(HAVE_LINEARSOLVERLOADER)
 
           options_to_print.push_back("#MA77 Linear Solver");
           options_to_print.push_back("ma77_print_level");
@@ -405,9 +384,45 @@ namespace Ipopt
           options_to_print.push_back("ma77_file_size");
           options_to_print.push_back("ma77_maxstore");
           options_to_print.push_back("ma77_nemin");
+#if defined(COINHSL_HSL2013) || defined(HAVE_LINEARSOLVERLOADER)
+          options_to_print.push_back("ma77_order");
+#endif
           options_to_print.push_back("ma77_small");
           options_to_print.push_back("ma77_static");
           options_to_print.push_back("ma77_u");
+          options_to_print.push_back("ma77_umax");
+#endif
+
+#if defined(COINHSL_HAS_MA86) || defined(HAVE_LINEARSOLVERLOADER)
+
+          options_to_print.push_back("#MA86 Linear Solver");
+          options_to_print.push_back("ma86_print_level");
+          options_to_print.push_back("ma86_nemin");
+          options_to_print.push_back("ma86_order");
+          options_to_print.push_back("ma86_scaling");
+          options_to_print.push_back("ma86_small");
+          options_to_print.push_back("ma86_static");
+          options_to_print.push_back("ma86_u");
+          options_to_print.push_back("ma86_umax");
+#endif
+
+#if defined(COINHSL_HAS_MA97) || defined(HAVE_LINEARSOLVERLOADER)
+
+          options_to_print.push_back("#MA97 Linear Solver");
+          options_to_print.push_back("ma97_print_level");
+          options_to_print.push_back("ma97_nemin");
+          options_to_print.push_back("ma97_order");
+          options_to_print.push_back("ma97_scaling");
+          options_to_print.push_back("ma97_scaling1");
+          options_to_print.push_back("ma97_scaling2");
+          options_to_print.push_back("ma97_scaling3");
+          options_to_print.push_back("ma97_small");
+          options_to_print.push_back("ma97_solve_blas3");
+          options_to_print.push_back("ma97_switch1");
+          options_to_print.push_back("ma97_switch2");
+          options_to_print.push_back("ma97_switch3");
+          options_to_print.push_back("ma97_u");
+          options_to_print.push_back("ma97_umax");
 #endif
 
 #ifdef COIN_HAS_MUMPS
@@ -496,7 +511,7 @@ namespace Ipopt
       exc.ReportException(*jnlst_, J_ERROR);
       return Unrecoverable_Exception;
     }
-    catch (std::bad_alloc) {
+    catch (std::bad_alloc&) {
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Not enough memory.\n");
       return Insufficient_Memory;
     }
@@ -508,6 +523,42 @@ namespace Ipopt
     return Solve_Succeeded;
   }
 
+  ApplicationReturnStatus
+  IpoptApplication::Initialize(std::string params_file)
+  {
+    std::ifstream is;
+    if (params_file != "") {
+      try {
+        is.open(params_file.c_str());
+      }
+      catch (std::bad_alloc&) {
+        jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Not enough memory.\n");
+        return Insufficient_Memory;
+      }
+      catch (...) {
+        IpoptException exc("Unknown Exception caught in ipopt", "Unknown File", -1);
+        exc.ReportException(*jnlst_);
+        return NonIpopt_Exception_Thrown;
+      }
+    }
+    ApplicationReturnStatus retval = Initialize(is);
+    if (is) {
+      is.close();
+    }
+    return retval;
+  }
+
+  ApplicationReturnStatus
+  IpoptApplication::Initialize()
+  {
+     std::string option_file_name;
+     options_->GetStringValue("option_file_name", option_file_name, "");
+     if (option_file_name != "" && option_file_name != "ipopt.opt")
+        jnlst_->Printf(J_SUMMARY, J_MAIN, "Using option file \"%s\".\n\n", option_file_name.c_str());
+
+     return Initialize(option_file_name);
+  }
+
   IpoptApplication::~IpoptApplication()
   {
     DBG_START_METH("IpoptApplication::~IpoptApplication()",
@@ -585,14 +636,15 @@ namespace Ipopt
 
     roptions->AddStringOption1(
       "option_file_name",
-      "File name of options file (to overwrite default).",
-      "",
+      "File name of options file.",
+      "ipopt.opt",
       "*", "Any acceptable standard file name",
       "By default, the name of the Ipopt options file is \"ipopt.opt\" - or "
       "something else if specified in the IpoptApplication::Initialize call. "
       "If this option is set by SetStringValue BEFORE the options file is "
       "read, it specifies the name of the options file.  It does not make any "
-      "sense to specify this option within the options file.");
+      "sense to specify this option within the options file. "
+      "Setting this option to an empty string disables reading of an options file.");
 
     roptions->AddStringOption2(
       "replace_bounds",
@@ -708,7 +760,7 @@ namespace Ipopt
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Some uncaught Ipopt exception encountered.\n");
       retValue = Unrecoverable_Exception;
     }
-    catch (std::bad_alloc) {
+    catch (std::bad_alloc&) {
       retValue = Insufficient_Memory;
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Not enough memory.\n");
     }
@@ -771,6 +823,9 @@ namespace Ipopt
 
     ApplicationReturnStatus retValue = Internal_Error;
     SolverReturn status = INTERNAL_ERROR;
+    /** Flag indicating if the NLP:FinalizeSolution method should not
+     *  be called after optimization. */
+    bool skip_finalize_solution_call = false;
     try {
 
       // Set up the algorithm
@@ -811,28 +866,34 @@ namespace Ipopt
                      p2ip_data->iter_count());
 
       if (status!=INVALID_NUMBER_DETECTED) {
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "\n                                   (scaled)                 (unscaled)\n");
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "Objective...............: %24.16e  %24.16e\n",
-                       p2ip_cq->curr_f(),
-                       p2ip_cq->unscaled_curr_f());
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "Dual infeasibility......: %24.16e  %24.16e\n",
-                       p2ip_cq->curr_dual_infeasibility(NORM_MAX),
-                       p2ip_cq->unscaled_curr_dual_infeasibility(NORM_MAX));
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "Constraint violation....: %24.16e  %24.16e\n",
-                       p2ip_cq->curr_nlp_constraint_violation(NORM_MAX),
-                       p2ip_cq->unscaled_curr_nlp_constraint_violation(NORM_MAX));
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "Complementarity.........: %24.16e  %24.16e\n",
-                       p2ip_cq->curr_complementarity(0., NORM_MAX),
-                       p2ip_cq->unscaled_curr_complementarity(0., NORM_MAX));
-        jnlst_->Printf(J_SUMMARY, J_SOLUTION,
-                       "Overall NLP error.......: %24.16e  %24.16e\n\n",
-                       p2ip_cq->curr_nlp_error(),
-                       p2ip_cq->unscaled_curr_nlp_error());
+        try {
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "\n                                   (scaled)                 (unscaled)\n");
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "Objective...............: %24.16e  %24.16e\n",
+                         p2ip_cq->curr_f(),
+                         p2ip_cq->unscaled_curr_f());
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "Dual infeasibility......: %24.16e  %24.16e\n",
+                         p2ip_cq->curr_dual_infeasibility(NORM_MAX),
+                         p2ip_cq->unscaled_curr_dual_infeasibility(NORM_MAX));
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "Constraint violation....: %24.16e  %24.16e\n",
+                         p2ip_cq->curr_nlp_constraint_violation(NORM_MAX),
+                         p2ip_cq->unscaled_curr_nlp_constraint_violation(NORM_MAX));
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "Complementarity.........: %24.16e  %24.16e\n",
+                         p2ip_cq->curr_complementarity(0., NORM_MAX),
+                         p2ip_cq->unscaled_curr_complementarity(0., NORM_MAX));
+          jnlst_->Printf(J_SUMMARY, J_SOLUTION,
+                         "Overall NLP error.......: %24.16e  %24.16e\n\n",
+                         p2ip_cq->curr_nlp_error(),
+                         p2ip_cq->unscaled_curr_nlp_error());
+        }
+        catch (IpoptNLP::Eval_Error& exc) {
+          status = INVALID_NUMBER_DETECTED;
+          exc.ReportException(*jnlst_, J_ERROR);
+        }
       }
 
       p2ip_data->curr()->x()->Print(*jnlst_, J_VECTOR, J_SOLUTION, "x");
@@ -916,7 +977,7 @@ namespace Ipopt
       }
       else if (status == DIVERGING_ITERATES) {
         retValue = Diverging_Iterates;
-        jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Iterates divering; problem might be unbounded.\n");
+        jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Iterates diverging; problem might be unbounded.\n");
       }
       else if (status == RESTORATION_FAILURE) {
         retValue = Restoration_Failed;
@@ -966,19 +1027,21 @@ namespace Ipopt
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Optimal Solution Found.\n");
       retValue = Solve_Succeeded;
       status = SUCCESS;
+      skip_finalize_solution_call = true; /* has already been called by TNLPAdapter (and we don't know the correct primal solution) */
     }
     catch (NO_FREE_VARIABLES_AND_INFEASIBLE& exc) {
       exc.ReportException(*jnlst_, J_MOREDETAILED);
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Problem has only fixed variables and constraints are infeasible.\n");
       retValue = Infeasible_Problem_Detected;
       status = LOCAL_INFEASIBILITY;
+      skip_finalize_solution_call = true; /* has already been called by TNLPAdapter (and we don't know the correct primal solution) */
     }
     catch (IpoptException& exc) {
       exc.ReportException(*jnlst_, J_ERROR);
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Some uncaught Ipopt exception encountered.\n");
       retValue = Unrecoverable_Exception;
     }
-    catch (std::bad_alloc) {
+    catch (std::bad_alloc&) {
       retValue = Insufficient_Memory;
       jnlst_->Printf(J_SUMMARY, J_MAIN, "\nEXIT: Not enough memory.\n");
       status = OUT_OF_MEMORY;
@@ -989,7 +1052,10 @@ namespace Ipopt
       retValue = NonIpopt_Exception_Thrown;
     }
 
-    if (IsValid(p2ip_data->curr()) && IsValid(p2ip_data->curr()->x())) {
+    if (!skip_finalize_solution_call)
+      options_->GetBoolValue("skip_finalize_solution_call", skip_finalize_solution_call, "");
+
+    if (!skip_finalize_solution_call && IsValid(p2ip_data->curr()) && IsValid(p2ip_data->curr()->x())) {
       SmartPtr<const Vector> c;
       SmartPtr<const Vector> d;
       SmartPtr<const Vector> zL;
@@ -1035,15 +1101,10 @@ namespace Ipopt
         }
       }
 
-      options_->GetBoolValue("skip_finalize_solution_call",
-                             skip_finalize_solution_call_, "");
-
-      if (!skip_finalize_solution_call_) {
-        p2ip_nlp->FinalizeSolution(status,
-                                   *p2ip_data->curr()->x(),
-                                   *zL, *zU, *c, *d, *yc, *yd,
-                                   obj, p2ip_data, p2ip_cq);
-      }
+      p2ip_nlp->FinalizeSolution(status,
+                                 *p2ip_data->curr()->x(),
+                                 *zL, *zU, *c, *d, *yc, *yd,
+                                 obj, p2ip_data, p2ip_cq);
     }
 
     jnlst_->FlushBuffer();
